==> dispcalgui_3.1.0.0.orig.tar.gz: DisplayCAL-3.1.0.0/DisplayCAL/report/compare.constants.js <==
var DELTA_A_MAX = 'DELTA_A_MAX',
	DELTA_A_AVG = 'DELTA_A_AVG',
	DELTA_A_MED = 'DELTA_A_MED', // Median
	DELTA_A_MAD = 'DELTA_A_MAD', // Median absolute deviation
	DELTA_A_RANGE = 'DELTA_A_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
									 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	DELTA_A_STDDEV = 'DELTA_A_STDDEV', // Standard deviation
	
	DELTA_A_B_RANGE = 'DELTA_A_B_RANGE', // The 'range' between two delta a b values is calculated as follows: abs(delta_a - delta_b)
										 // e.g. if delta_a = -0.2 and delta_b = 0.3, the range is 0.5
	
	DELTA_B_MAX = 'DELTA_B_MAX',
	DELTA_B_AVG = 'DELTA_B_AVG',
	DELTA_B_MED = 'DELTA_B_MED', // Median
	DELTA_B_MAD = 'DELTA_B_MAD', // Median absolute deviation
	DELTA_B_RANGE = 'DELTA_B_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
									 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	DELTA_B_STDDEV = 'DELTA_B_STDDEV', // Standard deviation
	
	DELTA_E_MAX = 'DELTA_E_MAX',
	DELTA_E_AVG = 'DELTA_E_AVG',
	DELTA_E_MED = 'DELTA_E_MED', // Median
	DELTA_E_MAD = 'DELTA_E_MAD', // Median absolute deviation
	DELTA_E_RANGE = 'DELTA_E_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
									 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	DELTA_E_STDDEV = 'DELTA_E_STDDEV', // Standard deviation
	
	DELTA_L_MAX = 'DELTA_L_MAX',
	DELTA_L_AVG = 'DELTA_L_AVG',
	DELTA_L_MED = 'DELTA_L_MED', // Median
	DELTA_L_MAD = 'DELTA_L_MAD', // Median absolute deviation
	DELTA_L_RANGE = 'DELTA_L_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
									 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	DELTA_L_STDDEV = 'DELTA_L_STDDEV', // Standard deviation
	
	DELTA_C_MAX = 'DELTA_C_MAX',
	DELTA_C_AVG = 'DELTA_C_AVG',
	DELTA_C_MED = 'DELTA_C_MED', // Median
	DELTA_C_MAD = 'DELTA_C_MAD', // Median absolute deviation
	DELTA_C_RANGE = 'DELTA_C_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
									 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	DELTA_C_STDDEV = 'DELTA_C_STDDEV', // Standard deviation
	
	DELTA_H_MAX = 'DELTA_H_MAX',
	DELTA_H_AVG = 'DELTA_H_AVG',
	DELTA_H_MED = 'DELTA_H_MED', // Median
	DELTA_H_MAD = 'DELTA_H_MAD', // Median absolute deviation
	DELTA_H_RANGE = 'DELTA_H_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
									 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	DELTA_H_STDDEV = 'DELTA_H_STDDEV', // Standard deviation
	
	GAMMA_MAX = 'GAMMA_MAX',
	GAMMA_MIN = 'GAMMA_MIN',
	GAMMA_AVG = 'GAMMA_AVG',
	GAMMA_MED = 'GAMMA_MED', // Median
	GAMMA_MAD = 'GAMMA_MAD', // Median absolute deviation
	GAMMA_RANGE = 'GAMMA_RANGE', // The 'range' between two delta values is calculated as follows: abs(delta1 - delta2)
								 // e.g. if delta1 = -0.2 and delta2 = 0.3, the range is 0.5
	GAMMA_STDDEV = 'GAMMA_STDDEV', // Standard deviation
	
	CIE76 = 'CIE76',
	CIE94 = 'CIE94',
	CIE00 = 'CIE00',
	CMC11 = 'CMC11',
	CMC21 = 'CMC21';

==> dispcalgui_3.5.0.0.orig.tar.gz: DisplayCAL-3.5.0.0/DisplayCAL/report/compare.constants.js <==
var DELTA_A_MAX = 'DELTA_A_MAX',
	DELTA_A_AVG = 'DELTA_A_AVG',
	DELTA_A_MED = 'DELTA_A_MED', // Median
	DELTA_A_MAD = 'DELTA_A_MAD', // Median absolute deviation
	DELTA_A_PERCENTILE_95 = 'DELTA_A_PERCENTILE_95',
	DELTA_A_PERCENTILE_99 = 'DELTA_A_PERCENTILE_99',
	DELTA_A_RANGE = 'DELTA_A_RANGE',
	DELTA_A_STDDEV = 'DELTA_A_STDDEV', // Standard deviation
	
	DELTA_A_B_RANGE = 'DELTA_A_B_RANGE',
	
	DELTA_B_MAX = 'DELTA_B_MAX',
	DELTA_B_AVG = 'DELTA_B_AVG',
	DELTA_B_MED = 'DELTA_B_MED', // Median
	DELTA_B_MAD = 'DELTA_B_MAD', // Median absolute deviation
	DELTA_B_PERCENTILE_95 = 'DELTA_B_PERCENTILE_95',
	DELTA_B_PERCENTILE_99 = 'DELTA_B_PERCENTILE_99',
	DELTA_B_RANGE = 'DELTA_B_RANGE',
	DELTA_B_STDDEV = 'DELTA_B_STDDEV', // Standard deviation
	
	DELTA_E_MAX = 'DELTA_E_MAX',
	DELTA_E_AVG = 'DELTA_E_AVG',
	DELTA_E_MED = 'DELTA_E_MED', // Median
	DELTA_E_MAD = 'DELTA_E_MAD', // Median absolute deviation
	DELTA_E_PERCENTILE_95 = 'DELTA_E_PERCENTILE_95',
	DELTA_E_PERCENTILE_99 = 'DELTA_E_PERCENTILE_99',
	DELTA_E_RANGE = 'DELTA_E_RANGE',
	DELTA_E_STDDEV = 'DELTA_E_STDDEV', // Standard deviation
	
	DELTA_L_MAX = 'DELTA_L_MAX',
	DELTA_L_AVG = 'DELTA_L_AVG',
	DELTA_L_MED = 'DELTA_L_MED', // Median
	DELTA_L_MAD = 'DELTA_L_MAD', // Median absolute deviation
	DELTA_L_PERCENTILE_95 = 'DELTA_L_PERCENTILE_95',
	DELTA_L_PERCENTILE_99 = 'DELTA_L_PERCENTILE_99',
	DELTA_L_RANGE = 'DELTA_L_RANGE',
	DELTA_L_STDDEV = 'DELTA_L_STDDEV', // Standard deviation
	
	DELTA_C_MAX = 'DELTA_C_MAX',
	DELTA_C_AVG = 'DELTA_C_AVG',
	DELTA_C_MED = 'DELTA_C_MED', // Median
	DELTA_C_MAD = 'DELTA_C_MAD', // Median absolute deviation
	DELTA_C_PERCENTILE_95 = 'DELTA_C_PERCENTILE_95',
	DELTA_C_PERCENTILE_99 = 'DELTA_C_PERCENTILE_99',
	DELTA_C_RANGE = 'DELTA_C_RANGE',
	DELTA_C_STDDEV = 'DELTA_C_STDDEV', // Standard deviation
	
	DELTA_H_MAX = 'DELTA_H_MAX',
	DELTA_H_AVG = 'DELTA_H_AVG',
	DELTA_H_MED = 'DELTA_H_MED', // Median
	DELTA_H_MAD = 'DELTA_H_MAD', // Median absolute deviation
	DELTA_H_PERCENTILE_95 = 'DELTA_H_PERCENTILE_95',
	DELTA_H_PERCENTILE_99 = 'DELTA_H_PERCENTILE_99',
	DELTA_H_RANGE = 'DELTA_H_RANGE',
	DELTA_H_STDDEV = 'DELTA_H_STDDEV', // Standard deviation
	
	GAMMA_MAX = 'GAMMA_MAX',
	GAMMA_MIN = 'GAMMA_MIN',
	GAMMA_AVG = 'GAMMA_AVG',
	GAMMA_MED = 'GAMMA_MED', // Median
	GAMMA_MAD = 'GAMMA_MAD', // Median absolute deviation
	GAMMA_PERCENTILE_95 = 'GAMMA_PERCENTILE_95',
	GAMMA_PERCENTILE_99 = 'GAMMA_PERCENTILE_99',
	GAMMA_RANGE = 'GAMMA_RANGE',
	GAMMA_STDDEV = 'GAMMA_STDDEV', // Standard deviation
	
	CIE76 = 'CIE76',
	CIE94 = 'CIE94',
	CIE00 = 'CIE00',
	CMC11 = 'CMC11',
	CMC21 = 'CMC21';
